package beilv.session.service.impl;

import java.util.List;

import beilv.session.domain.BeilvSession;
import beilv.session.mapper.BeilvSessionMapper;
import beilv.session.service.IBeilvSessionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import beilv.common.core.text.Convert;

/**
 * 时段管理Service业务层处理
 *
 * @author lc
 * @date 2025-01-06
 */
@Service
public class BeilvSessionServiceImpl implements IBeilvSessionService {
    @Autowired
    private BeilvSessionMapper beilvSessionMapper;

    /**
     * 查询时段管理
     *
     * @param id 时段管理主键
     * @return 时段管理
     */
    @Override
    public BeilvSession selectBeilvSessionById(Long id) {
        return beilvSessionMapper.selectBeilvSessionById(id);
    }

    /**
     * 查询时段管理列表
     *
     * @param beilvSession 时段管理
     * @return 时段管理
     */
    @Override
    public List<BeilvSession> selectBeilvSessionList(BeilvSession beilvSession) {
        return beilvSessionMapper.selectBeilvSessionList(beilvSession);
    }

    /**
     * 新增时段管理
     *
     * @param beilvSession 时段管理
     * @return 结果
     */
    @Override
    public int insertBeilvSession(BeilvSession beilvSession) {
        //验证当前球场的当前时段中当前类型的数据是否存在, 存在返回true; 不存在返回false
        if (beilvSessionMapper.selectOne(beilvSession)) {
            return -1;
        } else {
            return beilvSessionMapper.insertBeilvSession(beilvSession);
        }
    }

    /**
     * 修改时段管理
     *
     * @param beilvSession 时段管理
     * @return 结果
     */
    @Override
    public int updateBeilvSession(BeilvSession beilvSession) {
        if (beilvSessionMapper.selectOne(beilvSession)) {
            return -1;
        } else {
            return beilvSessionMapper.updateBeilvSession(beilvSession);
        }
    }

    /**
     * 批量删除时段管理
     *
     * @param ids 需要删除的时段管理主键
     * @return 结果
     */
    @Override
    public int deleteBeilvSessionByIds(String ids) {
        return beilvSessionMapper.deleteBeilvSessionByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除时段管理信息
     *
     * @param id 时段管理主键
     * @return 结果
     */
    @Override
    public int deleteBeilvSessionById(Long id) {
        return beilvSessionMapper.deleteBeilvSessionById(id);
    }

    @Override
    public List<BeilvSession> getAllToList() {
        return beilvSessionMapper.getAllToList();
    }
}
