package beilv.system.service.impl;

import java.util.List;

import beilv.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.stereotype.Service;
import beilv.common.core.text.Convert;
import beilv.system.domain.SysNotice;
import beilv.system.mapper.SysNoticeMapper;
import beilv.system.service.ISysNoticeService;

/**
 * 公告 服务层实现
 * 
 * @author ruoyi
 * @date 2018-06-25
 */
@Service
public class SysNoticeServiceImpl implements ISysNoticeService
{
    @Autowired
    private SysNoticeMapper noticeMapper;

    /**
     * 查询公告信息
     * 
     * @param noticeId 公告ID
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById(Long noticeId)
    {
        return noticeMapper.selectNoticeById(noticeId);
    }

    /**
     * 查询公告列表
     * 
     * @param notice 公告信息
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList(SysNotice notice)
    {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 新增公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int insertNotice(SysNotice notice)
    {
        notice.setReleaseTime(DateUtils.getNowDate());
        return noticeMapper.insertNotice(notice);
    }

    /**
     * 修改公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int updateNotice(SysNotice notice)
    {
        notice.setReleaseTime(DateUtils.getNowDate());
//        List<SysNotice> top = noticeMapper.getTopNotice(notice);
//        if (top != null && !top.isEmpty() && notice.getTopped().equals("Y")) {
//            // 已有置顶记录，且新的置顶状态为 "Y" 但不是同一个记录
//            boolean isSameNotice = top.stream()
//                    .anyMatch(existingNotice -> existingNotice.getNoticeId().equals(notice.getNoticeId()));
//            if (!isSameNotice) {
//                throw new DataIntegrityViolationException("已有置顶公告，请修改状态再进行设置");
//            }
//        }
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds(String ids)
    {
        return noticeMapper.deleteNoticeByIds(Convert.toStrArray(ids));
    }

    @Override
    public List<SysNotice> selectNoticeListApp(SysNotice notice)
    {
        return noticeMapper.selectNoticeListApp(notice);
    }

    @Override
    public int selectNoticeCount(SysNotice notice)
    {
        return noticeMapper.selectNoticeCount(notice);
    }
}
